pub struct SqliteSyncConfig { /* private fields */ }Expand description
Bounded configuration for one SQLite sync database.
Implementations
Sourceimpl SqliteSyncConfig
impl SqliteSyncConfig
Sourcepub fn new(path: impl Into<PathBuf>) -> Self
pub fn new(path: impl Into<PathBuf>) -> Self
Creates a configuration with conservative production bounds.
Sourcepub fn with_max_database_bytes(self, value: u64) -> Self
pub fn with_max_database_bytes(self, value: u64) -> Self
Selects the maximum database size in bytes.
Sourcepub fn with_max_outbox_entries(self, value: usize) -> Self
pub fn with_max_outbox_entries(self, value: usize) -> Self
Selects the maximum number of pending outbox entries.
Sourcepub fn with_max_checkpoints(self, value: usize) -> Self
pub fn with_max_checkpoints(self, value: usize) -> Self
Selects the maximum number of peer checkpoints.
Sourcepub fn with_max_outbox_record_bytes(self, value: usize) -> Self
pub fn with_max_outbox_record_bytes(self, value: usize) -> Self
Selects the maximum encoded size of one outbox entry.
Sourcepub fn with_max_read_records(self, value: usize) -> Self
pub fn with_max_read_records(self, value: usize) -> Self
Selects the maximum record count returned by one log read.
Sourcepub fn with_max_read_bytes(self, value: usize) -> Self
pub fn with_max_read_bytes(self, value: usize) -> Self
Selects the maximum payload bytes returned by one log read.
Sourcepub fn with_max_tombstones(self, value: usize) -> Self
pub fn with_max_tombstones(self, value: usize) -> Self
Selects the maximum retained tombstone count.
Sourcepub fn with_max_connections(self, value: usize) -> Self
pub fn with_max_connections(self, value: usize) -> Self
Selects the maximum number of simultaneously open SQLite connections.
Sourcepub fn with_busy_timeout_ms(self, value: u64) -> Self
pub fn with_busy_timeout_ms(self, value: u64) -> Self
Selects the SQLite writer-admission timeout in milliseconds.
Sourcepub fn with_backup_pages_per_step(self, value: i32) -> Self
pub fn with_backup_pages_per_step(self, value: i32) -> Self
Selects the number of pages copied by each online-backup step.