pub struct SqliteSyncStore { /* private fields */ }Expand description
Shared owner of one bounded SQLite sync database.
Implementations
Sourceimpl SqliteSyncStore
impl SqliteSyncStore
Sourcepub fn online_backup(
&self,
destination: impl AsRef<Path>,
) -> SqliteSyncResult<SqliteBackupReport>
pub fn online_backup( &self, destination: impl AsRef<Path>, ) -> SqliteSyncResult<SqliteBackupReport>
Creates an integrity-checked online backup and atomically publishes it.
Sourcepub fn restore_backup_to_new(
backup_path: impl AsRef<Path>,
destination: impl AsRef<Path>,
) -> SqliteSyncResult<SqliteBackupReport>
pub fn restore_backup_to_new( backup_path: impl AsRef<Path>, destination: impl AsRef<Path>, ) -> SqliteSyncResult<SqliteBackupReport>
Restores a verified backup into a new, previously absent database path.
Sourceimpl SqliteSyncStore
impl SqliteSyncStore
Sourcepub fn open(config: SqliteSyncConfig) -> SqliteSyncResult<Self>
pub fn open(config: SqliteSyncConfig) -> SqliteSyncResult<Self>
Opens, migrates and integrity-checks one provider database.
Sourcepub fn health(&self) -> SqliteSyncResult<SqliteSyncHealth>
pub fn health(&self) -> SqliteSyncResult<SqliteSyncHealth>
Runs an integrity check and reports bounded database usage.
Sourcepub fn config(&self) -> &SqliteSyncConfig
pub fn config(&self) -> &SqliteSyncConfig
Returns the provider’s redacted configuration bounds.
Sourcepub fn replication_log(&self) -> SqliteReplicationLog
pub fn replication_log(&self) -> SqliteReplicationLog
Creates a replication-log handle backed by this database.
Sourcepub fn checkpoint_store(&self) -> SqliteSyncCheckpointStore
pub fn checkpoint_store(&self) -> SqliteSyncCheckpointStore
Creates a checkpoint-store handle backed by this database.
Sourcepub fn outbox(&self) -> SqliteSyncOutbox
pub fn outbox(&self) -> SqliteSyncOutbox
Creates an outbox handle backed by this database.
Sourcepub fn tombstone_store(&self) -> SqliteSyncTombstoneStore
pub fn tombstone_store(&self) -> SqliteSyncTombstoneStore
Creates an opaque tombstone-store handle backed by this database.