pub struct SqliteSyncTombstoneStore { /* private fields */ }Expand description
Bounded SQLite tombstone storage for conservative deletion replication.
Implementations
Sourceimpl SqliteSyncTombstoneStore
impl SqliteSyncTombstoneStore
Sourcepub fn record(&self, tombstone: &SqliteSyncTombstone) -> SqliteSyncResult<bool>
pub fn record(&self, tombstone: &SqliteSyncTombstone) -> SqliteSyncResult<bool>
Atomically inserts or advances one opaque deletion marker.
Sourcepub fn active(
&self,
now_ms: u64,
limit: usize,
) -> SqliteSyncResult<Vec<SqliteSyncTombstone>>
pub fn active( &self, now_ms: u64, limit: usize, ) -> SqliteSyncResult<Vec<SqliteSyncTombstone>>
Returns at most limit unexpired markers in deterministic order.
Sourcepub fn prune_expired(
&self,
now_ms: u64,
limit: usize,
) -> SqliteSyncResult<usize>
pub fn prune_expired( &self, now_ms: u64, limit: usize, ) -> SqliteSyncResult<usize>
Deletes at most limit expired markers and returns the deletion count.
Sourcepub fn len(&self) -> SqliteSyncResult<usize>
pub fn len(&self) -> SqliteSyncResult<usize>
Returns the current retained marker count.
Sourcepub fn is_empty(&self) -> SqliteSyncResult<bool>
pub fn is_empty(&self) -> SqliteSyncResult<bool>
Reports whether no markers are retained.